<?php

namespace Drupal\entity_agree;

use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface defining an entity_agree_agreement entity.
 */
interface AgreementInterface extends EntityOwnerInterface {

  /**
   * Gets the node creation timestamp.
   *
   * @return int
   *   Creation timestamp of the node.
   */
  public function getCreatedTime();

  /**
   * Get the entity type ID of the agreed-to entity.
   *
   * @return string
   *   The entity type ID of the agreed-to entity.
   */
  public function getTargetEntityTypeId();

  /**
   * Get the entity ID of the agreed-to entity.
   *
   * @return string
   *   The entity ID of the agreed-to entity.
   */
  public function getTargetEntityId();

  /**
   * Get the entity revision ID of the agreed-to entity.
   *
   * @return string
   *   The entity revision ID of the agreed-to entity.
   */
  public function getTargetEntityRevisionId();

}
