<?php

namespace Drupal\entity_agree\Plugin\views\filter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\entity_agree\Plugin\views\AgreementViewsPluginTrait;
use Drupal\views\Plugin\views\filter\FilterPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Filter plugin for agreement status.
 *
 * @ViewsFilter("entity_agree_agreement_status")
 */
class AgreementStatus extends FilterPluginBase implements ContainerFactoryPluginInterface {

  use AgreementViewsPluginTrait;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $field = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $field->entityRepository = $container->get('entity.repository');
    return $field;
  }

  /**
   * {@inheritdoc}
   */
  public function defineOptions() {
    return $this->defineStatusOptions(parent::defineOptions());
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    $form['pending_text'] = $this->buildStatusOptionElement($this->t('Pending text'), $this->options['pending_text']);
    $form['complete_text'] = $this->buildStatusOptionElement($this->t('Complete text'), $this->options['complete_text']);
    parent::buildOptionsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function valueForm(&$form, FormStateInterface $form_state) {
    $form['value'] = [
      '#type' => 'select',
      '#title' => $this->t('Status'),
      '#options' => [
        'pending' => $this->options['pending_text'],
        'complete' => $this->options['complete_text'],
      ],
      '#default_value' => $this->value,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function adminSummary() {
    if (empty($this->value)) {
      return $this->options['pending_text'];
    }
    return $this->options['complete_text'];
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    $this->ensureMyTable();
    $operator = $this->value[0] == 'pending' ? 'IS NULL' : 'IS NOT NULL';
    $this->query->addWhere($this->options['group'], "$this->tableAlias.$this->realField", NULL, $operator);
  }

}
